==> apache-geode-1.14.4-src.tgz: apache-geode-1.14.4-src/extensions/geode-modules/src/main/java/org/apache/geode/modules/session/catalina/DeltaSessionManagerConfiguration.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package org.apache.geode.modules.session.catalina;

/**
 * Method used by Catalina XML configuration.
 */
@SuppressWarnings("unused")
interface DeltaSessionManagerConfiguration {

  void setRegionName(String regionName);

  String getRegionName();

  void setEnableLocalCache(boolean enableLocalCache);

  boolean getEnableLocalCache();

  void setMaxActiveSessions(int maxActiveSessions);

  int getMaxActiveSessions();

  void setRegionAttributesId(String regionType);

  String getRegionAttributesId();

  void setEnableGatewayDeltaReplication(boolean enableGatewayDeltaReplication);

  boolean getEnableGatewayDeltaReplication();

  void setEnableGatewayReplication(boolean enableGatewayReplication);

  boolean getEnableGatewayReplication();

  void setEnableDebugListener(boolean enableDebugListener);

  boolean getEnableDebugListener();

  boolean isCommitValveEnabled();

  void setEnableCommitValve(boolean enable);

  boolean isCommitValveFailfastEnabled();

  void setEnableCommitValveFailfast(boolean enable);

  boolean isBackingCacheAvailable();

  /**
   * @deprecated No replacement. Always prefer deserialized form.
   */
  @Deprecated
  void setPreferDeserializedForm(boolean enable);

  /**
   * @deprecated No replacement. Always prefer deserialized form.
   */
  @Deprecated
  boolean getPreferDeserializedForm();

}

==> apache-geode-1.15.2-src.tgz: apache-geode-1.15.2-src/extensions/geode-modules/src/main/java/org/apache/geode/modules/session/catalina/DeltaSessionManagerConfiguration.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package org.apache.geode.modules.session.catalina;

/**
 * Method used by Catalina XML configuration.
 */
@SuppressWarnings("unused")
interface DeltaSessionManagerConfiguration {

  void setRegionName(String regionName);

  String getRegionName();

  void setEnableLocalCache(boolean enableLocalCache);

  boolean getEnableLocalCache();

  void setMaxActiveSessions(int maxActiveSessions);

  int getMaxActiveSessions();

  void setRegionAttributesId(String regionType);

  String getRegionAttributesId();

  void setEnableGatewayDeltaReplication(boolean enableGatewayDeltaReplication);

  boolean getEnableGatewayDeltaReplication();

  void setEnableGatewayReplication(boolean enableGatewayReplication);

  boolean getEnableGatewayReplication();

  void setEnableDebugListener(boolean enableDebugListener);

  boolean getEnableDebugListener();

  boolean isCommitValveEnabled();

  void setEnableCommitValve(boolean enable);

  boolean isCommitValveFailfastEnabled();

  void setEnableCommitValveFailfast(boolean enable);

  boolean isBackingCacheAvailable();

  /**
   * @param enable boolean specifying whether to prefer deserialized form
   *
   * @deprecated No replacement. Always prefer deserialized form.
   */
  @Deprecated
  void setPreferDeserializedForm(boolean enable);

  /**
   * @return whether to prefer deserialized form
   *
   * @deprecated No replacement. Always prefer deserialized form.
   */
  @Deprecated
  boolean getPreferDeserializedForm();

}
